@@ -1,17 +1,18 @@
 # coding=utf-8
-from __future__ import (absolute_import, unicode_literals, division,
-                        print_function)
+from __future__ import (
+    absolute_import, division, print_function, unicode_literals
+)
 
 import logging
 
 import requests
-from requests.adapters import HTTPAdapter
 import slumber
+from requests.adapters import HTTPAdapter
 
 from closeio.exceptions import CloseIOError
-from closeio.utils import DummyCookieJar, paginate, handle_errors, \
-    parse_response, convert
-
+from closeio.utils import (
+    DummyCookieJar, convert, handle_errors, paginate, parse_response
+)
 
 logger = logging.getLogger(__name__)
 
@@ -46,6 +47,11 @@ class CloseIO(object):
     def get_lead(self, lead_id):
         return self._api.lead(lead_id).get()
 
+    @parse_response
+    @handle_errors
+    def get_contact(self, contact_id):
+        return self._api.contact(contact_id).get()
+
     @parse_response
     @handle_errors
     def delete_lead(self, lead_id):
@@ -287,6 +293,13 @@ class CloseIO(object):
             lead_id=lead_id,
         )
 
+    @parse_response
+    @handle_errors
+    def get_activities(self):
+        return paginate(
+            self._api.activity.get,
+        )
+
     @parse_response
     @handle_errors
     def get_opportunities(self):
